webpackJsonp([79],{mq4x:function(e,n,r){(function(e){"use strict";var n="undefined"!=typeof window&&void 0!==window.flatpickr?window.flatpickr:{l10ns:{}},r={weekdays:{shorthand:["Ned","Pon","Tor","Sre","Čet","Pet","Sob"],longhand:["Nedelja","Ponedeljek","Torek","Sreda","Četrtek","Petek","Sobota"]},months:{shorthand:["Jan","Feb","Mar","Apr","Maj","Jun","Jul","Avg","Sep","Okt","Nov","Dec"],longhand:["Januar","Februar","Marec","April","Maj","Junij","Julij","Avgust","September","Oktober","November","December"]},firstDayOfWeek:1,rangeSeparator:" do ",ordinal:function(){return"."}};n.l10ns.sl=r;var o=n.l10ns;e.Slovenian=r,e.default=o,Object.defineProperty(e,"__esModule",{value:!0})})(n)}});
//# sourceMappingURL=79.923e3aefcf94c30adb6a.js.map