webpackJsonp([78],{"5cHf":function(n,r,t){(function(n){"use strict";var r="undefined"!=typeof window&&void 0!==window.flatpickr?window.flatpickr:{l10ns:{}},t={weekdays:{shorthand:["Di","Hë","Ma","Më","En","Pr","Sh"],longhand:["E Diel","E Hënë","E Martë","E Mërkurë","E Enjte","E Premte","E Shtunë"]},months:{shorthand:["Jan","Shk","Mar","Pri","Maj","Qer","Kor","Gus","Sht","Tet","Nën","Dhj"],longhand:["Janar","Shkurt","Mars","Prill","Maj","Qershor","Korrik","Gusht","Shtator","Tetor","Nëntor","Dhjetor"]}};r.l10ns.sq=t;var a=r.l10ns;n.Albanian=t,n.default=a,Object.defineProperty(n,"__esModule",{value:!0})})(r)}});
//# sourceMappingURL=78.9252310ffb60c45b1470.js.map