webpackJsonp([103],{eytu:function(n,e,o){(function(n){"use strict";var e="undefined"!=typeof window&&void 0!==window.flatpickr?window.flatpickr:{l10ns:{}},o={weekdays:{shorthand:["א","ב","ג","ד","ה","ו","ז"],longhand:["ראשון","שני","שלישי","רביעי","חמישי","שישי","שבת"]},months:{shorthand:["ינו׳","פבר׳","מרץ","אפר׳","מאי","יוני","יולי","אוג׳","ספט׳","אוק׳","נוב׳","דצמ׳"],longhand:["ינואר","פברואר","מרץ","אפריל","מאי","יוני","יולי","אוגוסט","ספטמבר","אוקטובר","נובמבר","דצמבר"]}};e.l10ns.he=o;var d=e.l10ns;n.Hebrew=o,n.default=d,Object.defineProperty(n,"__esModule",{value:!0})})(e)}});
//# sourceMappingURL=103.71ce1ba4d70ccf90b742.js.map