// calendar module mutations
export const SET_CALENDARS = 'SET_CALENDARS'
export const ADD_CALENDAR = 'ADD_CALENDAR'
export const UPDATE_CALENDAR = 'UPDATE_CALENDAR'
export const DELETE_CALENDAR = 'DELETE_CALENDAR'
export const SET_SHARED_CALENDARS = 'SET_SHARED_CALENDARS'
export const ADD_SHARED_CALENDAR = 'ADD_SHARED_CALENDAR'
export const UPDATE_SHARED_CALENDAR = 'UPDATE_SHARED_CALENDAR'
export const DELETE_SHARED_CALENDAR = 'DELETE_SHARED_CALENDAR'

// event module mutations
export const SET_ATTENDEES = 'SET_ATTENDEES'
