webpackJsonp([88],{dHqq:function(e,n,a){(function(e){"use strict";var n="undefined"!=typeof window&&void 0!==window.flatpickr?window.flatpickr:{l10ns:{}},a={weekdays:{shorthand:["zo","ma","di","wo","do","vr","za"],longhand:["zondag","maandag","dinsdag","woensdag","donderdag","vrijdag","zaterdag"]},months:{shorthand:["jan","feb","mrt","apr","mei","jun","jul","aug","sept","okt","nov","dec"],longhand:["januari","februari","maart","april","mei","juni","juli","augustus","september","oktober","november","december"]},firstDayOfWeek:1,weekAbbreviation:"wk",rangeSeparator:" tot ",scrollTitle:"Scroll voor volgende / vorige",toggleTitle:"Klik om te wisselen",ordinal:function(e){return 1===e||8===e||e>=20?"ste":"de"}};n.l10ns.nl=a;var o=n.l10ns;e.Dutch=a,e.default=o,Object.defineProperty(e,"__esModule",{value:!0})})(n)}});
//# sourceMappingURL=88.363462f145f40ac77e99.js.map