webpackJsonp([114],{"9zMb":function(d,e,n){(function(d){"use strict";var e="undefined"!=typeof window&&void 0!==window.flatpickr?window.flatpickr:{l10ns:{}},n={weekdays:{shorthand:["Sul","Llun","Maw","Mer","Iau","Gwe","Sad"],longhand:["Dydd Sul","Dydd Llun","Dydd Mawrth","Dydd Mercher","Dydd Iau","Dydd Gwener","Dydd Sadwrn"]},months:{shorthand:["Ion","Chwef","Maw","Ebr","Mai","Meh","Gorff","Awst","Medi","Hyd","Tach","Rhag"],longhand:["Ionawr","Chwefror","Mawrth","Ebrill","Mai","Mehefin","Gorffennaf","Awst","Medi","Hydref","Tachwedd","Rhagfyr"]},firstDayOfWeek:1,ordinal:function(d){return 1===d?"af":2===d?"ail":3===d||4===d?"ydd":5===d||6===d?"ed":d>=7&&d<=10||12==d||15==d||18==d||20==d?"fed":11==d||13==d||14==d||16==d||17==d||19==d?"eg":d>=21&&d<=39?"ain":""}};e.l10ns.cy=n;var a=e.l10ns;d.Welsh=n,d.default=a,Object.defineProperty(d,"__esModule",{value:!0})})(e)}});
//# sourceMappingURL=114.ded6a8d757db29d604c8.js.map