webpackJsonp([73],{uMcs:function(n,e,a){(function(n){"use strict";var e="undefined"!=typeof window&&void 0!==window.flatpickr?window.flatpickr:{l10ns:{}},a={firstDayOfWeek:1,weekdays:{shorthand:["Нд","Пн","Вт","Ср","Чт","Пт","Сб"],longhand:["Неділя","Понеділок","Вівторок","Середа","Четвер","П'ятниця","Субота"]},months:{shorthand:["Січ","Лют","Бер","Кві","Тра","Чер","Лип","Сер","Вер","Жов","Лис","Гру"],longhand:["Січень","Лютий","Березень","Квітень","Травень","Червень","Липень","Серпень","Вересень","Жовтень","Листопад","Грудень"]}};e.l10ns.uk=a;var o=e.l10ns;n.Ukrainian=a,n.default=o,Object.defineProperty(n,"__esModule",{value:!0})})(e)}});
//# sourceMappingURL=73.ef61fd8523588b10391f.js.map