webpackJsonp([92],{hJKr:function(n,e,a){(function(n){"use strict";var e="undefined"!=typeof window&&void 0!==window.flatpickr?window.flatpickr:{l10ns:{}},a={weekdays:{shorthand:["Не","По","Вт","Ср","Че","Пе","Са"],longhand:["Недела","Понеделник","Вторник","Среда","Четврток","Петок","Сабота"]},months:{shorthand:["Јан","Фев","Мар","Апр","Мај","Јун","Јул","Авг","Сеп","Окт","Ное","Дек"],longhand:["Јануари","Февруари","Март","Април","Мај","Јуни","Јули","Август","Септември","Октомври","Ноември","Декември"]},firstDayOfWeek:1,weekAbbreviation:"Нед.",rangeSeparator:" до "};e.l10ns.mk=a;var o=e.l10ns;n.Macedonian=a,n.default=o,Object.defineProperty(n,"__esModule",{value:!0})})(e)}});
//# sourceMappingURL=92.70a1f8b5f1df0a86bc4f.js.map