webpackJsonp([80],{FAOw:function(e,n,o){(function(e){"use strict";var n="undefined"!=typeof window&&void 0!==window.flatpickr?window.flatpickr:{l10ns:{}},o={weekdays:{shorthand:["Ned","Pon","Ut","Str","Štv","Pia","Sob"],longhand:["Nedeľa","Pondelok","Utorok","Streda","Štvrtok","Piatok","Sobota"]},months:{shorthand:["Jan","Feb","Mar","Apr","Máj","Jún","Júl","Aug","Sep","Okt","Nov","Dec"],longhand:["Január","Február","Marec","Apríl","Máj","Jún","Júl","August","September","Október","November","December"]},firstDayOfWeek:1,rangeSeparator:" do ",ordinal:function(){return"."}};n.l10ns.sk=o;var r=n.l10ns;e.Slovak=o,e.default=r,Object.defineProperty(e,"__esModule",{value:!0})})(n)}});
//# sourceMappingURL=80.739c49795d3ef7036277.js.map