webpackJsonp([118],{ibRV:function(n,e,o){(function(n){"use strict";var e="undefined"!=typeof window&&void 0!==window.flatpickr?window.flatpickr:{l10ns:{}},o={weekdays:{shorthand:["Нд","Пн","Вт","Ср","Чт","Пт","Сб"],longhand:["Неделя","Понеделник","Вторник","Сряда","Четвъртък","Петък","Събота"]},months:{shorthand:["Яну","Фев","Март","Апр","Май","Юни","Юли","Авг","Сеп","Окт","Ное","Дек"],longhand:["Януари","Февруари","Март","Април","Май","Юни","Юли","Август","Септември","Октомври","Ноември","Декември"]}};e.l10ns.bg=o;var a=e.l10ns;n.Bulgarian=o,n.default=a,Object.defineProperty(n,"__esModule",{value:!0})})(e)}});
//# sourceMappingURL=118.b2457900a0d2e576f261.js.map