webpackJsonp([96],{pMXA:function(n,e,a){(function(n){"use strict";var e="undefined"!=typeof window&&void 0!==window.flatpickr?window.flatpickr:{l10ns:{}},a={weekdays:{shorthand:["日","月","火","水","木","金","土"],longhand:["日曜日","月曜日","火曜日","水曜日","木曜日","金曜日","土曜日"]},months:{shorthand:["1月","2月","3月","4月","5月","6月","7月","8月","9月","10月","11月","12月"],longhand:["1月","2月","3月","4月","5月","6月","7月","8月","9月","10月","11月","12月"]}};e.l10ns.ja=a;var o=e.l10ns;n.Japanese=a,n.default=o,Object.defineProperty(n,"__esModule",{value:!0})})(e)}});
//# sourceMappingURL=96.85adca162e4758ce66b5.js.map