webpackJsonp([76],{InMg:function(e,n,r){(function(e){"use strict";var n="undefined"!=typeof window&&void 0!==window.flatpickr?window.flatpickr:{l10ns:{}},r={firstDayOfWeek:1,weekAbbreviation:"v",weekdays:{shorthand:["Sön","Mån","Tis","Ons","Tor","Fre","Lör"],longhand:["Söndag","Måndag","Tisdag","Onsdag","Torsdag","Fredag","Lördag"]},months:{shorthand:["Jan","Feb","Mar","Apr","Maj","Jun","Jul","Aug","Sep","Okt","Nov","Dec"],longhand:["Januari","Februari","Mars","April","Maj","Juni","Juli","Augusti","September","Oktober","November","December"]},ordinal:function(){return"."}};n.l10ns.sv=r;var a=n.l10ns;e.Swedish=r,e.default=a,Object.defineProperty(e,"__esModule",{value:!0})})(n)}});
//# sourceMappingURL=76.236a36d0feab76fdd99b.js.map