webpackJsonp([84],{xfSO:function(e,o,a){(function(e){"use strict";var o="undefined"!=typeof window&&void 0!==window.flatpickr?window.flatpickr:{l10ns:{}},a={weekdays:{shorthand:["Dom","Seg","Ter","Qua","Qui","Sex","Sáb"],longhand:["Domingo","Segunda-feira","Terça-feira","Quarta-feira","Quinta-feira","Sexta-feira","Sábado"]},months:{shorthand:["Jan","Fev","Mar","Abr","Mai","Jun","Jul","Ago","Set","Out","Nov","Dez"],longhand:["Janeiro","Fevereiro","Março","Abril","Maio","Junho","Julho","Agosto","Setembro","Outubro","Novembro","Dezembro"]},rangeSeparator:" até "};o.l10ns.pt=a;var r=o.l10ns;e.Portuguese=a,e.default=r,Object.defineProperty(e,"__esModule",{value:!0})})(o)}});
//# sourceMappingURL=84.8f53ad4f9c8bd1db6742.js.map