webpackJsonp([99],{"8xjY":function(e,n,a){(function(e){"use strict";var n="undefined"!=typeof window&&void 0!==window.flatpickr?window.flatpickr:{l10ns:{}},a={weekdays:{shorthand:["Min","Sen","Sel","Rab","Kam","Jum","Sab"],longhand:["Minggu","Senin","Selasa","Rabu","Kamis","Jumat","Sabtu"]},months:{shorthand:["Jan","Feb","Mar","Apr","Mei","Jun","Jul","Agu","Sep","Okt","Nov","Des"],longhand:["Januari","Februari","Maret","April","Mei","Juni","Juli","Agustus","September","Oktober","November","Desember"]},firstDayOfWeek:1,ordinal:function(){return""}};n.l10ns.id=a;var i=n.l10ns;e.Indonesian=a,e.default=i,Object.defineProperty(e,"__esModule",{value:!0})})(n)}});
//# sourceMappingURL=99.d926d97187028de8f2fb.js.map