webpackJsonp([90],{ZJ0p:function(n,a,e){(function(n){"use strict";var a=("undefined"!=typeof window&&void 0!==window.flatpickr?window.flatpickr:{l10ns:{}}).l10ns;n.Malaysian={weekdays:{shorthand:["Min","Isn","Sel","Rab","Kha","Jum","Sab"],longhand:["Minggu","Isnin","Selasa","Rabu","Khamis","Jumaat","Sabtu"]},months:{shorthand:["Jan","Feb","Mac","Apr","Mei","Jun","Jul","Ogo","Sep","Okt","Nov","Dis"],longhand:["Januari","Februari","Mac","April","Mei","Jun","Julai","Ogos","September","Oktober","November","Disember"]},firstDayOfWeek:1,ordinal:function(){return""}},n.default=a,Object.defineProperty(n,"__esModule",{value:!0})})(a)}});
//# sourceMappingURL=90.fb8d86586edd4a7f0d68.js.map