webpackJsonp([71],{VV2Z:function(n,e,o){(function(n){"use strict";var e="undefined"!=typeof window&&void 0!==window.flatpickr?window.flatpickr:{l10ns:{}},o={weekdays:{shorthand:["周日","周一","周二","周三","周四","周五","周六"],longhand:["星期日","星期一","星期二","星期三","星期四","星期五","星期六"]},months:{shorthand:["一月","二月","三月","四月","五月","六月","七月","八月","九月","十月","十一月","十二月"],longhand:["一月","二月","三月","四月","五月","六月","七月","八月","九月","十月","十一月","十二月"]},rangeSeparator:" 至 ",weekAbbreviation:"周",scrollTitle:"滚动切换",toggleTitle:"点击切换 12/24 小时时制"};e.l10ns.zh=o;var a=e.l10ns;n.Mandarin=o,n.default=a,Object.defineProperty(n,"__esModule",{value:!0})})(e)}});
//# sourceMappingURL=71.3a917f3b2d395b098c39.js.map