webpackJsonp([93],{iz5y:function(e,i,n){(function(e){"use strict";var i="undefined"!=typeof window&&void 0!==window.flatpickr?window.flatpickr:{l10ns:{}},n={firstDayOfWeek:1,weekdays:{shorthand:["Sv","P","Ot","Tr","Ce","Pk","Se"],longhand:["Svētdiena","Pirmdiena","Otrdiena","Trešdiena","Ceturtdiena","Piektdiena","Sestdiena"]},months:{shorthand:["Jan","Feb","Mar","Mai","Apr","Jūn","Jūl","Aug","Sep","Okt","Nov","Dec"],longhand:["Janvāris","Februāris","Marts","Aprīlis","Maijs","Jūnijs","Jūlijs","Augusts","Septembris","Oktobris","Novembris","Decembris"]},rangeSeparator:" līdz "};i.l10ns.lv=n;var a=i.l10ns;e.Latvian=n,e.default=a,Object.defineProperty(e,"__esModule",{value:!0})})(i)}});
//# sourceMappingURL=93.6f8911c0785a9ef490bf.js.map