{% extends "fluid.html" %}

{% load i18n lib_tags static %}
{% load render_bundle from webpack_loader %}

{% block pagetitle %}{% trans "Calendar" %}{% endblock %}

{% block extra_css %}
  {% render_bundle 'app' 'css' 'CALENDAR' %}
{% endblock %}

{% block extra_js %}
  {% if not debug %}
    {% render_bundle 'manifest' 'js' 'CALENDAR' %}
    {% render_bundle 'vendor' 'js' 'CALENDAR' %}
    {% render_bundle 'app' 'js' 'CALENDAR' %}
  {% else %}
    {% render_bundle 'app' 'js' 'CALENDAR' %}
  {% endif %}

  <script>
  window.userProfile = {
      isSuperUser: {% if user.is_superuser %}true{% else %}false{% endif %},
      permissions: [{% for perm in permissions %}'{{ perm }}'{% if not forloop.last %},{% endif %}{% endfor %}]
  };
  </script>
{% endblock %}

{% block container_content %}

  <div id="app">
  </div>

{% endblock %}
