webpackJsonp([85],{XzyY:function(e,i,n){(function(e){"use strict";var i="undefined"!=typeof window&&void 0!==window.flatpickr?window.flatpickr:{l10ns:{}},n={weekdays:{shorthand:["Nd","Pn","Wt","Śr","Cz","Pt","So"],longhand:["Niedziela","Poniedziałek","Wtorek","Środa","Czwartek","Piątek","Sobota"]},months:{shorthand:["Sty","Lut","Mar","Kwi","Maj","Cze","Lip","Sie","Wrz","Paź","Lis","Gru"],longhand:["Styczeń","Luty","Marzec","Kwiecień","Maj","Czerwiec","Lipiec","Sierpień","Wrzesień","Październik","Listopad","Grudzień"]},firstDayOfWeek:1,ordinal:function(){return"."}};i.l10ns.pl=n;var t=i.l10ns;e.Polish=n,e.default=t,Object.defineProperty(e,"__esModule",{value:!0})})(i)}});
//# sourceMappingURL=85.c29f270ab4c38a2e7a59.js.map